# This file is generated from pydcs_export.lua

from . import unittype


class Fortification:

    class Command_Center(unittype.StaticType):
        id = ".Command Center"
        name = "Command Center"
        shape_name = "ComCenter"
        rate = 100

    class Hangar_A(unittype.StaticType):
        id = "Hangar A"
        name = "Hangar A"
        shape_name = "angar_a"
        rate = 100

    class Tech_hangar_A(unittype.StaticType):
        id = "Tech hangar A"
        name = "Tech hangar A"
        shape_name = "ceh_ang_a"
        rate = 100

    class Farm_A(unittype.StaticType):
        id = "Farm A"
        name = "Farm A"
        shape_name = "ferma_a"
        rate = 100

    class Farm_B(unittype.StaticType):
        id = "Farm B"
        name = "Farm B"
        shape_name = "ferma_b"
        rate = 100

    class Garage_A(unittype.StaticType):
        id = "Garage A"
        name = "Garage A"
        shape_name = "garage_a"
        rate = 100

    class Boiler_house_A(unittype.StaticType):
        id = "Boiler-house A"
        name = "Boiler-house A"
        shape_name = "kotelnaya_a"
        rate = 100

    class Restaurant_1(unittype.StaticType):
        id = "Restaurant 1"
        name = "Restaurant 1"
        shape_name = "restoran1"
        rate = 100

    class Comms_tower_M(unittype.StaticType):
        id = "Comms tower M"
        name = "Comms tower M"
        shape_name = "tele_bash_m"
        rate = 100

    class Cafe(unittype.StaticType):
        id = "Cafe"
        name = "Cafe"
        shape_name = "stolovaya"
        rate = 100

    class Workshop_A(unittype.StaticType):
        id = "Workshop A"
        name = "Workshop A"
        shape_name = "tec_a"
        rate = 100

    class Electric_power_box(unittype.StaticType):
        id = "Electric power box"
        name = "Electric power box"
        shape_name = "tr_budka"
        rate = 100

    class Supermarket_A(unittype.StaticType):
        id = "Supermarket A"
        name = "Supermarket A"
        shape_name = "uniwersam_a"
        rate = 100

    class Water_tower_A(unittype.StaticType):
        id = "Water tower A"
        name = "Water tower A"
        shape_name = "wodokachka_a"
        rate = 100

    class TV_tower(unittype.StaticType):
        id = "TV tower"
        name = "TV tower"
        shape_name = "tele_bash"
        rate = 100

    class Shelter(unittype.StaticType):
        id = "Shelter"
        name = "Shelter"
        shape_name = "ukrytie"
        rate = 100

    class Repair_workshop(unittype.StaticType):
        id = "Repair workshop"
        name = "Repair workshop"
        shape_name = "tech"
        rate = 100

    class Railway_station(unittype.StaticType):
        id = "Railway station"
        name = "Railway station"
        shape_name = "r_vok_sd"
        rate = 100

    class Railway_crossing_A(unittype.StaticType):
        id = "Railway crossing A"
        name = "Railway crossing A"
        shape_name = "pereezd_big"
        rate = 100

    class Railway_crossing_B(unittype.StaticType):
        id = "Railway crossing B"
        name = "Railway crossing B"
        shape_name = "pereezd_small"
        rate = 100

    class WC(unittype.StaticType):
        id = "WC"
        name = "WC"
        shape_name = "WC"
        rate = 100

    class Small_house_1A_area(unittype.StaticType):
        id = "Small house 1A area"
        name = "Small house 1A area"
        shape_name = "domik1a-all"
        rate = 100

    class Small_house_1A(unittype.StaticType):
        id = "Small house 1A"
        name = "Small house 1A"
        shape_name = "domik1a"
        rate = 100

    class Small_house_1B_area(unittype.StaticType):
        id = "Small house 1B area"
        name = "Small house 1B area"
        shape_name = "domik1b-all"
        rate = 100

    class Small_house_1B(unittype.StaticType):
        id = "Small house 1B"
        name = "Small house 1B"
        shape_name = "domik1b"
        rate = 100

    class Small_house_1C_area(unittype.StaticType):
        id = "Small house 1C area"
        name = "Small house 1C area"
        shape_name = "dom2c-all"
        rate = 100

    class Small_house_2C(unittype.StaticType):
        id = "Small house 2C"
        name = "Small house 2C"
        shape_name = "dom2c"
        rate = 100

    class Shop(unittype.StaticType):
        id = "Shop"
        name = "Shop"
        shape_name = "magazin"
        rate = 100

    class Tech_combine(unittype.StaticType):
        id = "Tech combine"
        name = "Tech combine"
        shape_name = "kombinat"
        rate = 100

    class Chemical_tank_A(unittype.StaticType):
        id = "Chemical tank A"
        name = "Chemical tank A"
        shape_name = "him_bak_a"
        rate = 100

    class Small_warehouse_1(unittype.StaticType):
        id = "Small werehouse 1"
        name = "Small warehouse 1"
        shape_name = "s1"
        rate = 100

    class Small_warehouse_2(unittype.StaticType):
        id = "Small werehouse 2"
        name = "Small warehouse 2"
        shape_name = "s2"
        rate = 100

    class Small_warehouse_3(unittype.StaticType):
        id = "Small werehouse 3"
        name = "Small warehouse 3"
        shape_name = "s3"
        rate = 100

    class Small_warehouse_4(unittype.StaticType):
        id = "Small werehouse 4"
        name = "Small warehouse 4"
        shape_name = "s4"
        rate = 100

    class Garage_B(unittype.StaticType):
        id = "Garage B"
        name = "Garage B"
        shape_name = "garage_b"
        rate = 100

    class Garage_small_A(unittype.StaticType):
        id = "Garage small A"
        name = "Garage small A"
        shape_name = "garagh-small-a"
        rate = 100

    class Garage_small_B(unittype.StaticType):
        id = "Garage small B"
        name = "Garage small B"
        shape_name = "garagh-small-b"
        rate = 100

    class Pump_station(unittype.StaticType):
        id = "Pump station"
        name = "Pump station"
        shape_name = "nasos"
        rate = 100

    class Oil_derrick(unittype.StaticType):
        id = "Oil derrick"
        name = "Oil derrick"
        shape_name = "neftevyshka"
        rate = 100

    class Container_red_1(unittype.StaticType):
        id = "Container red 1"
        name = "Container red 1"
        shape_name = "konteiner_red1"
        rate = 100

    class Container_red_2(unittype.StaticType):
        id = "Container red 2"
        name = "Container red 2"
        shape_name = "konteiner_red2"
        rate = 100

    class Container_red_3(unittype.StaticType):
        id = "Container red 3"
        name = "Container red 3"
        shape_name = "konteiner_red3"
        rate = 100

    class Container_white(unittype.StaticType):
        id = "Container white"
        name = "Container white"
        shape_name = "konteiner_white"
        rate = 100

    class Container_brown(unittype.StaticType):
        id = "Container brown"
        name = "Container brown"
        shape_name = "konteiner_brown"
        rate = 100

    class Barracks_2(unittype.StaticType):
        id = "Barracks 2"
        name = "Barracks 2"
        shape_name = "kazarma2"
        rate = 100

    class Military_staff(unittype.StaticType):
        id = "Military staff"
        name = "Military staff"
        shape_name = "aviashtab"
        rate = 100

    class Hangar_B(unittype.StaticType):
        id = "Hangar B"
        name = "Hangar B"
        shape_name = "angar_b"
        rate = 100

    class Fuel_tank(unittype.StaticType):
        id = "Fuel tank"
        name = "Fuel tank"
        shape_name = "toplivo-bak"
        rate = 100

    class Shelter_B(unittype.StaticType):
        id = "Shelter B"
        name = "Shelter B"
        shape_name = "ukrytie_b"
        rate = 100

    class Oil_platform(unittype.StaticType):
        id = "Oil platform"
        name = "Oil platform"
        shape_name = "plavbaza"
        rate = 100
        sea_object = True

    class Subsidiary_structure_1(unittype.StaticType):
        id = "Subsidiary structure 1"
        name = "Subsidiary structure 1"
        shape_name = "hozdomik1"
        rate = 100

    class Subsidiary_structure_2(unittype.StaticType):
        id = "Subsidiary structure 2"
        name = "Subsidiary structure 2"
        shape_name = "hozdomik2"
        rate = 100

    class Subsidiary_structure_3(unittype.StaticType):
        id = "Subsidiary structure 3"
        name = "Subsidiary structure 3"
        shape_name = "hozdomik3"
        rate = 100

    class Subsidiary_structure_A(unittype.StaticType):
        id = "Subsidiary structure A"
        name = "Subsidiary structure A"
        shape_name = "saray-a"
        rate = 100

    class Subsidiary_structure_B(unittype.StaticType):
        id = "Subsidiary structure B"
        name = "Subsidiary structure B"
        shape_name = "saray-b"
        rate = 100

    class Subsidiary_structure_C(unittype.StaticType):
        id = "Subsidiary structure C"
        name = "Subsidiary structure C"
        shape_name = "saray-c"
        rate = 100

    class Subsidiary_structure_D(unittype.StaticType):
        id = "Subsidiary structure D"
        name = "Subsidiary structure D"
        shape_name = "saray-d"
        rate = 100

    class Subsidiary_structure_E(unittype.StaticType):
        id = "Subsidiary structure E"
        name = "Subsidiary structure E"
        shape_name = "saray-e"
        rate = 100

    class Subsidiary_structure_F(unittype.StaticType):
        id = "Subsidiary structure F"
        name = "Subsidiary structure F"
        shape_name = "saray-f"
        rate = 100

    class Subsidiary_structure_G(unittype.StaticType):
        id = "Subsidiary structure G"
        name = "Subsidiary structure G"
        shape_name = "saray-g"
        rate = 100

    class Landmine(unittype.StaticType):
        id = "Landmine"
        name = "Landmine"
        shape_name = "landmine"
        rate = 1

    class FARP_Ammo_Storage(unittype.StaticType):
        id = "FARP Ammo Dump Coating"
        name = "FARP Ammo Storage"
        shape_name = "SetkaKP"
        rate = 50

    class FARP_Tent(unittype.StaticType):
        id = "FARP Tent"
        name = "FARP Tent"
        shape_name = "PalatkaB"
        rate = 50

    class FARP_Command_Post(unittype.StaticType):
        id = "FARP CP Blindage"
        name = "FARP Command Post"
        shape_name = "kp_ug"
        rate = 100

    class FARP_Fuel_Depot(unittype.StaticType):
        id = "FARP Fuel Depot"
        name = "FARP Fuel Depot"
        shape_name = "GSM Rus"
        rate = 20

    class GeneratorF(unittype.StaticType):
        id = "GeneratorF"
        name = "GeneratorF"
        shape_name = "GeneratorF"
        rate = 100

    class Airshow_cone(unittype.StaticType):
        id = "Airshow_Cone"
        name = "Airshow cone"
        shape_name = "Comp_cone"
        rate = 100

    class Airshow_Crowd(unittype.StaticType):
        id = "Airshow_Crowd"
        name = "Airshow Crowd"
        shape_name = "Crowd1"
        rate = 100

    class Coach_a_tank_yellow(unittype.StaticType):
        id = "Coach a tank yellow"
        name = "Coach a tank yellow"
        shape_name = "wagon-cisterna_yellow"
        rate = 100

    class Coach_a_tank_blue(unittype.StaticType):
        id = "Coach a tank blue"
        name = "Coach a tank blue"
        shape_name = "wagon-cisterna_blue"
        rate = 100

    class Coach_for_cargo(unittype.StaticType):
        id = "Coach cargo"
        name = "Coach for cargo"
        shape_name = "wagon-gruz"
        rate = 100

    class Coach_for_open_cargo(unittype.StaticType):
        id = "Coach cargo open"
        name = "Coach for open cargo"
        shape_name = "wagon-gruz-otkr"
        rate = 100

    class Coach_flatbed(unittype.StaticType):
        id = "Coach a platform"
        name = "Coach flatbed"
        shape_name = "wagon-platforma"
        rate = 100

    class Coach_for_passengers(unittype.StaticType):
        id = "Coach a passenger"
        name = "Coach for passengers"
        shape_name = "wagon-pass"
        rate = 100

    class Electric_locomotive(unittype.StaticType):
        id = "Electric locomotive"
        name = "Electric locomotive"
        shape_name = "elektrowoz"
        rate = 100

    class Locomotive(unittype.StaticType):
        id = "Locomotive"
        name = "Locomotive"
        shape_name = "teplowoz"
        rate = 100

    class Mark_Flag_Red(unittype.StaticType):
        id = "Red_Flag"
        name = "Mark Flag Red"
        shape_name = "H-flag_R"
        rate = 3

    class Mark_Flag_White(unittype.StaticType):
        id = "White_Flag"
        name = "Mark Flag White"
        shape_name = "H-Flag_W"
        rate = 3

    class Mark_Tyre_Black(unittype.StaticType):
        id = "Black_Tyre"
        name = "Mark Tyre Black"
        shape_name = "H-tyre_B"
        rate = 3

    class Mark_Tyre_White(unittype.StaticType):
        id = "White_Tyre"
        name = "Mark Tyre White"
        shape_name = "H-tyre_W"
        rate = 3

    class Mark_Tyre_with_Red_Flag(unittype.StaticType):
        id = "Black_Tyre_RF"
        name = "Mark Tyre with Red Flag"
        shape_name = "H-tyre_B_RF"
        rate = 3

    class Mark_Tyre_with_White_Flag(unittype.StaticType):
        id = "Black_Tyre_WF"
        name = "Mark Tyre with White Flag"
        shape_name = "H-tyre_B_WF"
        rate = 3

    class Windsock(unittype.StaticType):
        id = "Windsock"
        name = "Windsock"
        shape_name = "H-Windsock_RW"
        rate = 3

fortification_map = {
    ".Command Center": Fortification.Command_Center,
    "Hangar A": Fortification.Hangar_A,
    "Tech hangar A": Fortification.Tech_hangar_A,
    "Farm A": Fortification.Farm_A,
    "Farm B": Fortification.Farm_B,
    "Garage A": Fortification.Garage_A,
    "Boiler-house A": Fortification.Boiler_house_A,
    "Restaurant 1": Fortification.Restaurant_1,
    "Comms tower M": Fortification.Comms_tower_M,
    "Cafe": Fortification.Cafe,
    "Workshop A": Fortification.Workshop_A,
    "Electric power box": Fortification.Electric_power_box,
    "Supermarket A": Fortification.Supermarket_A,
    "Water tower A": Fortification.Water_tower_A,
    "TV tower": Fortification.TV_tower,
    "Shelter": Fortification.Shelter,
    "Repair workshop": Fortification.Repair_workshop,
    "Railway station": Fortification.Railway_station,
    "Railway crossing A": Fortification.Railway_crossing_A,
    "Railway crossing B": Fortification.Railway_crossing_B,
    "WC": Fortification.WC,
    "Small house 1A area": Fortification.Small_house_1A_area,
    "Small house 1A": Fortification.Small_house_1A,
    "Small house 1B area": Fortification.Small_house_1B_area,
    "Small house 1B": Fortification.Small_house_1B,
    "Small house 1C area": Fortification.Small_house_1C_area,
    "Small house 2C": Fortification.Small_house_2C,
    "Shop": Fortification.Shop,
    "Tech combine": Fortification.Tech_combine,
    "Chemical tank A": Fortification.Chemical_tank_A,
    "Small werehouse 1": Fortification.Small_warehouse_1,
    "Small werehouse 2": Fortification.Small_warehouse_2,
    "Small werehouse 3": Fortification.Small_warehouse_3,
    "Small werehouse 4": Fortification.Small_warehouse_4,
    "Garage B": Fortification.Garage_B,
    "Garage small A": Fortification.Garage_small_A,
    "Garage small B": Fortification.Garage_small_B,
    "Pump station": Fortification.Pump_station,
    "Oil derrick": Fortification.Oil_derrick,
    "Container red 1": Fortification.Container_red_1,
    "Container red 2": Fortification.Container_red_2,
    "Container red 3": Fortification.Container_red_3,
    "Container white": Fortification.Container_white,
    "Container brown": Fortification.Container_brown,
    "Barracks 2": Fortification.Barracks_2,
    "Military staff": Fortification.Military_staff,
    "Hangar B": Fortification.Hangar_B,
    "Fuel tank": Fortification.Fuel_tank,
    "Shelter B": Fortification.Shelter_B,
    "Oil platform": Fortification.Oil_platform,
    "Subsidiary structure 1": Fortification.Subsidiary_structure_1,
    "Subsidiary structure 2": Fortification.Subsidiary_structure_2,
    "Subsidiary structure 3": Fortification.Subsidiary_structure_3,
    "Subsidiary structure A": Fortification.Subsidiary_structure_A,
    "Subsidiary structure B": Fortification.Subsidiary_structure_B,
    "Subsidiary structure C": Fortification.Subsidiary_structure_C,
    "Subsidiary structure D": Fortification.Subsidiary_structure_D,
    "Subsidiary structure E": Fortification.Subsidiary_structure_E,
    "Subsidiary structure F": Fortification.Subsidiary_structure_F,
    "Subsidiary structure G": Fortification.Subsidiary_structure_G,
    "Landmine": Fortification.Landmine,
    "FARP Ammo Dump Coating": Fortification.FARP_Ammo_Storage,
    "FARP Tent": Fortification.FARP_Tent,
    "FARP CP Blindage": Fortification.FARP_Command_Post,
    "FARP Fuel Depot": Fortification.FARP_Fuel_Depot,
    "GeneratorF": Fortification.GeneratorF,
    "Airshow_Cone": Fortification.Airshow_cone,
    "Airshow_Crowd": Fortification.Airshow_Crowd,
    "Coach a tank yellow": Fortification.Coach_a_tank_yellow,
    "Coach a tank blue": Fortification.Coach_a_tank_blue,
    "Coach cargo": Fortification.Coach_for_cargo,
    "Coach cargo open": Fortification.Coach_for_open_cargo,
    "Coach a platform": Fortification.Coach_flatbed,
    "Coach a passenger": Fortification.Coach_for_passengers,
    "Electric locomotive": Fortification.Electric_locomotive,
    "Locomotive": Fortification.Locomotive,
    "Red_Flag": Fortification.Mark_Flag_Red,
    "White_Flag": Fortification.Mark_Flag_White,
    "Black_Tyre": Fortification.Mark_Tyre_Black,
    "White_Tyre": Fortification.Mark_Tyre_White,
    "Black_Tyre_RF": Fortification.Mark_Tyre_with_Red_Flag,
    "Black_Tyre_WF": Fortification.Mark_Tyre_with_White_Flag,
    "Windsock": Fortification.Windsock,
}


class GroundObject:

    class Building(unittype.StaticType):
        id = "Building"
        name = "Building"
        category = ""

    class Bridge(unittype.StaticType):
        id = "Bridge"
        name = "Bridge"
        category = ""

    class Transport(unittype.StaticType):
        id = "Transport"
        name = "Transport"
        category = ""

    class Train(unittype.StaticType):
        id = "Train"
        name = "Train"
        category = ""

groundobject_map = {
    "Building": GroundObject.Building,
    "Bridge": GroundObject.Bridge,
    "Transport": GroundObject.Transport,
    "Train": GroundObject.Train,
}


class Warehouse:

    class Warehouse(unittype.StaticType):
        id = "Warehouse"
        name = "Warehouse"
        shape_name = "sklad"
        category = "Warehouses"
        rate = 100

    class Tank(unittype.StaticType):
        id = "Tank"
        name = "Tank"
        shape_name = "bak"
        category = "Warehouses"
        rate = 100

    class Ammunition_depot(unittype.StaticType):
        id = ".Ammunition depot"
        name = "Ammunition depot"
        shape_name = "SkladC"
        category = "Warehouses"
        rate = 100

    class Tank_2(unittype.StaticType):
        id = "Tank 2"
        name = "Tank 2"
        shape_name = "airbase_tbilisi_tank_01"
        category = "Warehouses"
        rate = 100

    class Tank_3(unittype.StaticType):
        id = "Tank 3"
        name = "Tank 3"
        shape_name = "airbase_tbilisi_tank_02"
        category = "Warehouses"
        rate = 100

warehouse_map = {
    "Warehouse": Warehouse.Warehouse,
    "Tank": Warehouse.Tank,
    ".Ammunition depot": Warehouse.Ammunition_depot,
    "Tank 2": Warehouse.Tank_2,
    "Tank 3": Warehouse.Tank_3,
}


class Cargo:

    class uh1h_cargo(unittype.StaticType):
        id = "uh1h_cargo"
        name = "uh1h_cargo"
        shape_name = "ab-212_cargo"
        category = "Cargos"
        rate = 100
        can_cargo = True

    class ammo_cargo(unittype.StaticType):
        id = "ammo_cargo"
        name = "ammo_cargo"
        shape_name = "ammo_box_cargo"
        category = "Cargos"
        rate = 1000
        can_cargo = True

    class f_bar_cargo(unittype.StaticType):
        id = "f_bar_cargo"
        name = "f_bar_cargo"
        shape_name = "f_bar_cargo"
        category = "Cargos"
        rate = 823
        can_cargo = True

    class m117_cargo(unittype.StaticType):
        id = "m117_cargo"
        name = "m117_cargo"
        shape_name = "m117_cargo"
        category = "Cargos"
        rate = 840
        can_cargo = True

    class iso_container(unittype.StaticType):
        id = "iso_container"
        name = "iso_container"
        shape_name = "iso_container_cargo"
        category = "Cargos"
        rate = 3800
        can_cargo = True

    class iso_container_small(unittype.StaticType):
        id = "iso_container_small"
        name = "iso_container_small"
        shape_name = "iso_container_small_cargo"
        category = "Cargos"
        rate = 220
        can_cargo = True

    class barrels_cargo(unittype.StaticType):
        id = "barrels_cargo"
        name = "barrels_cargo"
        shape_name = "barrels_cargo"
        category = "Cargos"
        rate = 480
        can_cargo = True

    class container_cargo(unittype.StaticType):
        id = "container_cargo"
        name = "container_cargo"
        shape_name = "bw_container_cargo"
        category = "Cargos"
        rate = 100
        can_cargo = True

    class tetrapod_cargo(unittype.StaticType):
        id = "tetrapod_cargo"
        name = "tetrapod_cargo"
        shape_name = "tetrapod_cargo"
        category = "Cargos"
        rate = 5000
        can_cargo = True

    class fueltank_cargo(unittype.StaticType):
        id = "fueltank_cargo"
        name = "fueltank_cargo"
        shape_name = "fueltank_cargo"
        category = "Cargos"
        rate = 800
        can_cargo = True

    class oiltank_cargo(unittype.StaticType):
        id = "oiltank_cargo"
        name = "oiltank_cargo"
        shape_name = "oiltank_cargo"
        category = "Cargos"
        rate = 700
        can_cargo = True

    class pipes_big_cargo(unittype.StaticType):
        id = "pipes_big_cargo"
        name = "pipes_big_cargo"
        shape_name = "pipes_big_cargo"
        category = "Cargos"
        rate = 4815
        can_cargo = True

    class pipes_small_cargo(unittype.StaticType):
        id = "pipes_small_cargo"
        name = "pipes_small_cargo"
        shape_name = "pipes_small_cargo"
        category = "Cargos"
        rate = 4350
        can_cargo = True

    class trunks_small_cargo(unittype.StaticType):
        id = "trunks_small_cargo"
        name = "trunks_small_cargo"
        shape_name = "trunks_small_cargo"
        category = "Cargos"
        rate = 5000
        can_cargo = True

    class trunks_long_cargo(unittype.StaticType):
        id = "trunks_long_cargo"
        name = "trunks_long_cargo"
        shape_name = "trunks_long_cargo"
        category = "Cargos"
        rate = 4747
        can_cargo = True

cargo_map = {
    "uh1h_cargo": Cargo.uh1h_cargo,
    "ammo_cargo": Cargo.ammo_cargo,
    "f_bar_cargo": Cargo.f_bar_cargo,
    "m117_cargo": Cargo.m117_cargo,
    "iso_container": Cargo.iso_container,
    "iso_container_small": Cargo.iso_container_small,
    "barrels_cargo": Cargo.barrels_cargo,
    "container_cargo": Cargo.container_cargo,
    "tetrapod_cargo": Cargo.tetrapod_cargo,
    "fueltank_cargo": Cargo.fueltank_cargo,
    "oiltank_cargo": Cargo.oiltank_cargo,
    "pipes_big_cargo": Cargo.pipes_big_cargo,
    "pipes_small_cargo": Cargo.pipes_small_cargo,
    "trunks_small_cargo": Cargo.trunks_small_cargo,
    "trunks_long_cargo": Cargo.trunks_long_cargo,
}
