# This file is generated from pydcs_export.lua

from . import unittype


class Fortification:

    class Bunker_2(unittype.VehicleType):
        id = "Bunker"
        name = "Bunker 2"

    class Bunker_1(unittype.VehicleType):
        id = "Sandbox"
        name = "Bunker 1"

    class Barracks_armed(unittype.VehicleType):
        id = "house1arm"
        name = "Barracks armed"

    class Watch_tower_armed(unittype.VehicleType):
        id = "house2arm"
        name = "Watch tower armed"

    class Road_outpost(unittype.VehicleType):
        id = "outpost_road"
        name = "Road outpost"

    class Outpost(unittype.VehicleType):
        id = "outpost"
        name = "Outpost"

    class Armed_house(unittype.VehicleType):
        id = "houseA_arm"
        name = "Armed house"


class Infantry:

    class Paratrooper_RPG_16(unittype.VehicleType):
        id = "Paratrooper RPG-16"
        name = "Paratrooper RPG-16"

    class Paratrooper_AKS(unittype.VehicleType):
        id = "Paratrooper AKS-74"
        name = "Paratrooper AKS"

    class Infantry_Soldier_Insurgents(unittype.VehicleType):
        id = "Infantry AK Ins"
        name = "Infantry Soldier Insurgents"

    class Soldier_AK(unittype.VehicleType):
        id = "Soldier AK"
        name = "Soldier AK"

    class Infantry_Soldier_Rus(unittype.VehicleType):
        id = "Infantry AK"
        name = "Infantry Soldier Rus"

    class Soldier_M249(unittype.VehicleType):
        id = "Soldier M249"
        name = "Soldier M249"

    class Infantry_M4(unittype.VehicleType):
        id = "Soldier M4"
        name = "Infantry M4"

    class Georgian_soldier_with_M4(unittype.VehicleType):
        id = "Soldier M4 GRG"
        name = "Georgian soldier with M4"

    class Soldier_RPG(unittype.VehicleType):
        id = "Soldier RPG"
        name = "Soldier RPG"


class Unarmed:

    class GPU_APA_5D_on_Ural_4320(unittype.VehicleType):
        id = "Ural-4320 APA-5D"
        name = "GPU APA-5D on Ural-4320"

    class Fuel_Truck_ATMZ_5(unittype.VehicleType):
        id = "ATMZ-5"
        name = "Fuel Truck ATMZ-5"

    class Fuel_Truck_ATZ_10(unittype.VehicleType):
        id = "ATZ-10"
        name = "Fuel Truck ATZ-10"

    class Transport_GAZ_3307(unittype.VehicleType):
        id = "GAZ-3307"
        name = "Transport GAZ-3307"

    class Transport_GAZ_3308(unittype.VehicleType):
        id = "GAZ-3308"
        name = "Transport GAZ-3308"

    class Transport_GAZ_66(unittype.VehicleType):
        id = "GAZ-66"
        name = "Transport GAZ-66"

    class Tanker_M978_HEMTT(unittype.VehicleType):
        id = "M978 HEMTT Tanker"
        name = "Tanker M978 HEMTT"

    class HEMTT_TFFT(unittype.VehicleType):
        id = "HEMTT TFFT"
        name = "HEMTT TFFT"

    class Transport_IKARUS_280(unittype.VehicleType):
        id = "IKARUS Bus"
        name = "Transport IKARUS-280"

    class Transport_KAMAZ_43101(unittype.VehicleType):
        id = "KAMAZ Truck"
        name = "Transport KAMAZ-43101"

    class Transport_LAZ_695(unittype.VehicleType):
        id = "LAZ Bus"
        name = "Transport LAZ-695"

    class APC_M1025_HMMWV(unittype.VehicleType):
        id = "Hummer"
        name = "APC M1025 HMMWV"
        eprls = True

    class Transport_M818(unittype.VehicleType):
        id = "M 818"
        name = "Transport M818"

    class Transport_MAZ_6303(unittype.VehicleType):
        id = "MAZ-6303"
        name = "Transport MAZ-6303"

    class CP_Predator_GCS(unittype.VehicleType):
        id = "Predator GCS"
        name = "CP Predator GCS"

    class CP_Predator_TrojanSpirit(unittype.VehicleType):
        id = "Predator TrojanSpirit"
        name = "CP Predator TrojanSpirit"

    class Suidae(unittype.VehicleType):
        id = "Suidae"
        name = "Suidae"

    class APC_Tigr_233036(unittype.VehicleType):
        id = "Tigr_233036"
        name = "APC Tigr 233036"

    class Transport_ZIU_9(unittype.VehicleType):
        id = "Trolley bus"
        name = "Transport ZIU-9"

    class Transport_UAZ_469(unittype.VehicleType):
        id = "UAZ-469"
        name = "Transport UAZ-469"

    class Transport_fire_Engine_Ural_ATsP_6(unittype.VehicleType):
        id = "Ural ATsP-6"
        name = "Transport fire-Engine Ural ATsP-6"

    class Transport_Ural_4320_31_Armored(unittype.VehicleType):
        id = "Ural-4320-31"
        name = "Transport Ural-4320-31 Armored"

    class Transport_Ural_4320T(unittype.VehicleType):
        id = "Ural-4320T"
        name = "Transport Ural-4320T"

    class CP_Ural_375_PBU(unittype.VehicleType):
        id = "Ural-375 PBU"
        name = "CP Ural-375 PBU"

    class Transport_Ural_375(unittype.VehicleType):
        id = "Ural-375"
        name = "Transport Ural-375"

    class Transport_VAZ_2109(unittype.VehicleType):
        id = "VAZ Car"
        name = "Transport VAZ-2109"

    class GPU_APA_80_on_ZiL_131(unittype.VehicleType):
        id = "ZiL-131 APA-80"
        name = "GPU APA-80 on ZiL-131"

    class CP_SKP_11_ATC_Mobile_Command_Post(unittype.VehicleType):
        id = "SKP-11"
        name = "CP SKP-11 ATC Mobile Command Post"

    class Transport_ZIL_131_KUNG(unittype.VehicleType):
        id = "ZIL-131 KUNG"
        name = "Transport ZIL-131 KUNG"

    class Transport_ZIL_4331(unittype.VehicleType):
        id = "ZIL-4331"
        name = "Transport ZIL-4331"

    class Transport_KrAZ_6322(unittype.VehicleType):
        id = "KrAZ6322"
        name = "Transport KrAZ-6322"


class Armor:

    class APC_AAV_7(unittype.VehicleType):
        id = "AAV7"
        name = "APC AAV-7"

    class IFV_BMD_1(unittype.VehicleType):
        id = "BMD-1"
        name = "IFV BMD-1"

    class IFV_BMP_1(unittype.VehicleType):
        id = "BMP-1"
        name = "IFV BMP-1"

    class IFV_BMP_2(unittype.VehicleType):
        id = "BMP-2"
        name = "IFV BMP-2"

    class IFV_BMP_3(unittype.VehicleType):
        id = "BMP-3"
        name = "IFV BMP-3"

    class ARV_BRDM_2(unittype.VehicleType):
        id = "BRDM-2"
        name = "ARV BRDM-2"

    class APC_BTR_80(unittype.VehicleType):
        id = "BTR-80"
        name = "APC BTR-80"

    class ARV_BTR_RD(unittype.VehicleType):
        id = "BTR_D"
        name = "ARV BTR-RD"

    class APC_Cobra(unittype.VehicleType):
        id = "Cobra"
        name = "APC Cobra"

    class IFV_LAV_25(unittype.VehicleType):
        id = "LAV-25"
        name = "IFV LAV-25"

    class APC_M1043_HMMWV_Armament(unittype.VehicleType):
        id = "M1043 HMMWV Armament"
        name = "APC M1043 HMMWV Armament"
        eprls = True

    class ATGM_M1045_HMMWV_TOW(unittype.VehicleType):
        id = "M1045 HMMWV TOW"
        name = "ATGM M1045 HMMWV TOW"
        eprls = True

    class APC_M1126_Stryker_ICV(unittype.VehicleType):
        id = "M1126 Stryker ICV"
        name = "APC M1126 Stryker ICV"
        eprls = True

    class APC_M113(unittype.VehicleType):
        id = "M-113"
        name = "APC M113"
        eprls = True

    class ATGM_M1134_Stryker(unittype.VehicleType):
        id = "M1134 Stryker ATGM"
        name = "ATGM M1134 Stryker"
        eprls = True

    class IFV_M2A2_Bradley(unittype.VehicleType):
        id = "M-2 Bradley"
        name = "IFV M2A2 Bradley"
        eprls = True

    class IFV_MCV_80(unittype.VehicleType):
        id = "MCV-80"
        name = "IFV MCV-80"

    class APC_MTLB(unittype.VehicleType):
        id = "MTLB"
        name = "APC MTLB"

    class IFV_Marder(unittype.VehicleType):
        id = "Marder"
        name = "IFV Marder"

    class TPz_Fuchs(unittype.VehicleType):
        id = "TPZ"
        name = "TPz Fuchs"

    class ARV_MTLB_U_BOMAN(unittype.VehicleType):
        id = "Boman"
        name = "ARV MTLB-U BOMAN"

    class MBT_Challenger_II(unittype.VehicleType):
        id = "Challenger2"
        name = "MBT Challenger II"

    class MBT_Leclerc(unittype.VehicleType):
        id = "Leclerc"
        name = "MBT Leclerc"

    class MBT_Leopard_2(unittype.VehicleType):
        id = "Leopard-2"
        name = "MBT Leopard-2"

    class MBT_M60A3_Patton(unittype.VehicleType):
        id = "M-60"
        name = "MBT M60A3 Patton"

    class SPG_M1128_Stryker_MGS(unittype.VehicleType):
        id = "M1128 Stryker MGS"
        name = "SPG M1128 Stryker MGS"
        eprls = True

    class MBT_M1A2_Abrams(unittype.VehicleType):
        id = "M-1 Abrams"
        name = "MBT M1A2 Abrams"
        eprls = True

    class MBT_T_55(unittype.VehicleType):
        id = "T-55"
        name = "MBT T-55"

    class MBT_T_72B(unittype.VehicleType):
        id = "T-72B"
        name = "MBT T-72B"

    class MBT_T_80U(unittype.VehicleType):
        id = "T-80UD"
        name = "MBT T-80U"

    class MBT_T_90(unittype.VehicleType):
        id = "T-90"
        name = "MBT T-90"

    class MBT_Leopard_1A3(unittype.VehicleType):
        id = "Leopard1A3"
        name = "MBT Leopard 1A3"

    class MBT_Merkava_Mk__4(unittype.VehicleType):
        id = "Merkava_Mk4"
        name = "MBT Merkava Mk. 4"


class Artillery:

    class _2B11_mortar(unittype.VehicleType):
        id = "2B11 mortar"
        name = "2B11 mortar"

    class SPH_2S1_Gvozdika(unittype.VehicleType):
        id = "SAU Gvozdika"
        name = "SPH 2S1 Gvozdika"

    class SPH_2S19_Msta(unittype.VehicleType):
        id = "SAU Msta"
        name = "SPH 2S19 Msta"

    class SPH_2S3_Akatsia(unittype.VehicleType):
        id = "SAU Akatsia"
        name = "SPH 2S3 Akatsia"

    class SPH_2S9_Nona(unittype.VehicleType):
        id = "SAU 2-C9"
        name = "SPH 2S9 Nona"

    class SPH_M109_Paladin(unittype.VehicleType):
        id = "M-109"
        name = "SPH M109 Paladin"
        eprls = True

    class MLRS_BM_21_Grad(unittype.VehicleType):
        id = "Grad-URAL"
        name = "MLRS BM-21 Grad"

    class MLRS_9K57_Uragan_BM_27(unittype.VehicleType):
        id = "Uragan_BM-27"
        name = "MLRS 9K57 Uragan BM-27"

    class MLRS_9A52_Smerch(unittype.VehicleType):
        id = "Smerch"
        name = "MLRS 9A52 Smerch"

    class MLRS_M270(unittype.VehicleType):
        id = "MLRS"
        name = "MLRS M270"
        eprls = True


class AirDefence:

    class SAM_SA_19_Tunguska_2S6(unittype.VehicleType):
        id = "2S6 Tunguska"
        name = "SAM SA-19 Tunguska 2S6"

    class SAM_SA_6_Kub_LN_2P25(unittype.VehicleType):
        id = "Kub 2P25 ln"
        name = "SAM SA-6 Kub LN 2P25"

    class SAM_SA_3_S_125_LN_5P73(unittype.VehicleType):
        id = "5p73 s-125 ln"
        name = "SAM SA-3 S-125 LN 5P73"

    class SAM_SA_10_S_300PS_LN_5P85C(unittype.VehicleType):
        id = "S-300PS 5P85C ln"
        name = "SAM SA-10 S-300PS LN 5P85C"

    class SAM_SA_10_S_300PS_LN_5P85D(unittype.VehicleType):
        id = "S-300PS 5P85D ln"
        name = "SAM SA-10 S-300PS LN 5P85D"

    class SAM_SA_11_Buk_LN_9A310M1(unittype.VehicleType):
        id = "SA-11 Buk LN 9A310M1"
        name = "SAM SA-11 Buk LN 9A310M1"

    class SAM_SA_8_Osa_9A33(unittype.VehicleType):
        id = "Osa 9A33 ln"
        name = "SAM SA-8 Osa 9A33"

    class SAM_SA_15_Tor_9A331(unittype.VehicleType):
        id = "Tor 9A331"
        name = "SAM SA-15 Tor 9A331"

    class SAM_SA_13_Strela_10M3_9A35M3(unittype.VehicleType):
        id = "Strela-10M3"
        name = "SAM SA-13 Strela-10M3 9A35M3"

    class SAM_SA_9_Strela_1_9P31(unittype.VehicleType):
        id = "Strela-1 9P31"
        name = "SAM SA-9 Strela-1 9P31"

    class SAM_SA_11_Buk_CC_9S470M1(unittype.VehicleType):
        id = "SA-11 Buk CC 9S470M1"
        name = "SAM SA-11 Buk CC 9S470M1"

    class SAM_SA_8_Osa_LD_9T217(unittype.VehicleType):
        id = "SA-8 Osa LD 9T217"
        name = "SAM SA-8 Osa LD 9T217"

    class SAM_Patriot_AMG_AN_MRC_137(unittype.VehicleType):
        id = "Patriot AMG"
        name = "SAM Patriot AMG AN/MRC-137"

    class SAM_Patriot_ECS_AN_MSQ_104(unittype.VehicleType):
        id = "Patriot ECS"
        name = "SAM Patriot ECS AN/MSQ-104"
        eprls = True

    class SPAAA_Gepard(unittype.VehicleType):
        id = "Gepard"
        name = "SPAAA Gepard"

    class SAM_Hawk_PCP(unittype.VehicleType):
        id = "Hawk pcp"
        name = "SAM Hawk PCP"

    class AAA_Vulcan_M163(unittype.VehicleType):
        id = "Vulcan"
        name = "AAA Vulcan M163"
        eprls = True

    class SAM_Hawk_LN_M192(unittype.VehicleType):
        id = "Hawk ln"
        name = "SAM Hawk LN M192"

    class SAM_Chaparral_M48(unittype.VehicleType):
        id = "M48 Chaparral"
        name = "SAM Chaparral M48"
        eprls = True

    class SAM_Linebacker_M6(unittype.VehicleType):
        id = "M6 Linebacker"
        name = "SAM Linebacker M6"
        eprls = True

    class SAM_Patriot_LN_M901(unittype.VehicleType):
        id = "Patriot ln"
        name = "SAM Patriot LN M901"

    class SAM_Avenger_M1097(unittype.VehicleType):
        id = "M1097 Avenger"
        name = "SAM Avenger M1097"
        eprls = True

    class SAM_Patriot_EPP_III(unittype.VehicleType):
        id = "Patriot EPP"
        name = "SAM Patriot EPP-III"

    class SAM_Patriot_ICC(unittype.VehicleType):
        id = "Patriot cp"
        name = "SAM Patriot ICC"

    class SAM_Roland_ADS(unittype.VehicleType):
        id = "Roland ADS"
        name = "SAM Roland ADS"

    class SAM_SA_10_S_300PS_CP_54K6(unittype.VehicleType):
        id = "S-300PS 54K6 cp"
        name = "SAM SA-10 S-300PS CP 54K6"

    class Stinger_MANPADS(unittype.VehicleType):
        id = "Soldier stinger"
        name = "Stinger MANPADS"

    class SAM_Stinger_comm_dsr(unittype.VehicleType):
        id = "Stinger comm dsr"
        name = "SAM Stinger comm dsr"

    class SAM_Stinger_comm(unittype.VehicleType):
        id = "Stinger comm"
        name = "SAM Stinger comm"

    class SPAAA_ZSU_23_4_Shilka(unittype.VehicleType):
        id = "ZSU-23-4 Shilka"
        name = "SPAAA ZSU-23-4 Shilka"

    class AAA_ZU_23_Closed(unittype.VehicleType):
        id = "ZU-23 Emplacement Closed"
        name = "AAA ZU-23 Closed"

    class AAA_ZU_23_Emplacement(unittype.VehicleType):
        id = "ZU-23 Emplacement"
        name = "AAA ZU-23 Emplacement"

    class AAA_ZU_23_on_Ural_375(unittype.VehicleType):
        id = "Ural-375 ZU-23"
        name = "AAA ZU-23 on Ural-375"

    class AAA_ZU_23_Insurgent_Closed(unittype.VehicleType):
        id = "ZU-23 Closed Insurgent"
        name = "AAA ZU-23 Insurgent Closed"

    class AAA_ZU_23_Insurgent_on_Ural_375(unittype.VehicleType):
        id = "Ural-375 ZU-23 Insurgent"
        name = "AAA ZU-23 Insurgent on Ural-375"

    class AAA_ZU_23_Insurgent(unittype.VehicleType):
        id = "ZU-23 Insurgent"
        name = "AAA ZU-23 Insurgent"

    class SAM_SA_18_Igla_MANPADS(unittype.VehicleType):
        id = "SA-18 Igla manpad"
        name = "SAM SA-18 Igla MANPADS"

    class SAM_SA_18_Igla_comm(unittype.VehicleType):
        id = "SA-18 Igla comm"
        name = "SAM SA-18 Igla comm"

    class SAM_SA_18_Igla_S_MANPADS(unittype.VehicleType):
        id = "SA-18 Igla-S manpad"
        name = "SAM SA-18 Igla-S MANPADS"

    class SAM_SA_18_Igla_S_comm(unittype.VehicleType):
        id = "SA-18 Igla-S comm"
        name = "SAM SA-18 Igla-S comm"

    class SAM_SA_18_Igla_MANPADS(unittype.VehicleType):
        id = "Igla manpad INS"
        name = "SAM SA-18 Igla MANPADS"

    class EWR_1L13(unittype.VehicleType):
        id = "1L13 EWR"
        name = "EWR 1L13"

    class SAM_SA_6_Kub_STR_9S91(unittype.VehicleType):
        id = "Kub 1S91 str"
        name = "SAM SA-6 Kub STR 9S91"

    class SAM_SA_10_S_300PS_TR_30N6(unittype.VehicleType):
        id = "S-300PS 40B6M tr"
        name = "SAM SA-10 S-300PS TR 30N6"

    class SAM_SA_10_S_300PS_SR_5N66M(unittype.VehicleType):
        id = "S-300PS 40B6MD sr"
        name = "SAM SA-10 S-300PS SR 5N66M"

    class EWR_55G6(unittype.VehicleType):
        id = "55G6 EWR"
        name = "EWR 55G6"

    class SAM_SA_10_S_300PS_SR_64H6E(unittype.VehicleType):
        id = "S-300PS 64H6E sr"
        name = "SAM SA-10 S-300PS SR 64H6E"

    class SAM_SA_11_Buk_SR_9S18M1(unittype.VehicleType):
        id = "SA-11 Buk SR 9S18M1"
        name = "SAM SA-11 Buk SR 9S18M1"

    class CP_9S80M1_Sborka(unittype.VehicleType):
        id = "Dog Ear radar"
        name = "CP 9S80M1 Sborka"

    class SAM_Hawk_TR_AN_MPQ_46(unittype.VehicleType):
        id = "Hawk tr"
        name = "SAM Hawk TR AN/MPQ-46"

    class SAM_Hawk_SR_AN_MPQ_50(unittype.VehicleType):
        id = "Hawk sr"
        name = "SAM Hawk SR AN/MPQ-50"
        eprls = True

    class SAM_Patriot_STR_AN_MPQ_53(unittype.VehicleType):
        id = "Patriot str"
        name = "SAM Patriot STR AN/MPQ-53"

    class SAM_Hawk_CWAR_AN_MPQ_55(unittype.VehicleType):
        id = "Hawk cwar"
        name = "SAM Hawk CWAR AN/MPQ-55"
        eprls = True

    class SAM_SA_3_S_125_SR_P_19(unittype.VehicleType):
        id = "p-19 s-125 sr"
        name = "SAM SA-3 S-125 SR P-19"

    class SAM_Roland_EWR(unittype.VehicleType):
        id = "Roland Radar"
        name = "SAM Roland EWR"

    class SAM_SA_3_S_125_TR_SNR(unittype.VehicleType):
        id = "snr s-125 tr"
        name = "SAM SA-3 S-125 TR SNR"

vehicle_map = {
    "2B11 mortar": Artillery._2B11_mortar,
    "SAU Gvozdika": Artillery.SPH_2S1_Gvozdika,
    "SAU Msta": Artillery.SPH_2S19_Msta,
    "SAU Akatsia": Artillery.SPH_2S3_Akatsia,
    "SAU 2-C9": Artillery.SPH_2S9_Nona,
    "M-109": Artillery.SPH_M109_Paladin,
    "AAV7": Armor.APC_AAV_7,
    "BMD-1": Armor.IFV_BMD_1,
    "BMP-1": Armor.IFV_BMP_1,
    "BMP-2": Armor.IFV_BMP_2,
    "BMP-3": Armor.IFV_BMP_3,
    "BRDM-2": Armor.ARV_BRDM_2,
    "BTR-80": Armor.APC_BTR_80,
    "BTR_D": Armor.ARV_BTR_RD,
    "Cobra": Armor.APC_Cobra,
    "LAV-25": Armor.IFV_LAV_25,
    "M1043 HMMWV Armament": Armor.APC_M1043_HMMWV_Armament,
    "M1045 HMMWV TOW": Armor.ATGM_M1045_HMMWV_TOW,
    "M1126 Stryker ICV": Armor.APC_M1126_Stryker_ICV,
    "M-113": Armor.APC_M113,
    "M1134 Stryker ATGM": Armor.ATGM_M1134_Stryker,
    "M-2 Bradley": Armor.IFV_M2A2_Bradley,
    "MCV-80": Armor.IFV_MCV_80,
    "MTLB": Armor.APC_MTLB,
    "Marder": Armor.IFV_Marder,
    "TPZ": Armor.TPz_Fuchs,
    "Boman": Armor.ARV_MTLB_U_BOMAN,
    "Bunker": Fortification.Bunker_2,
    "Paratrooper RPG-16": Infantry.Paratrooper_RPG_16,
    "Paratrooper AKS-74": Infantry.Paratrooper_AKS,
    "Infantry AK Ins": Infantry.Infantry_Soldier_Insurgents,
    "Sandbox": Fortification.Bunker_1,
    "Soldier AK": Infantry.Soldier_AK,
    "Infantry AK": Infantry.Infantry_Soldier_Rus,
    "Soldier M249": Infantry.Soldier_M249,
    "Soldier M4": Infantry.Infantry_M4,
    "Soldier M4 GRG": Infantry.Georgian_soldier_with_M4,
    "Soldier RPG": Infantry.Soldier_RPG,
    "Grad-URAL": Artillery.MLRS_BM_21_Grad,
    "Uragan_BM-27": Artillery.MLRS_9K57_Uragan_BM_27,
    "Smerch": Artillery.MLRS_9A52_Smerch,
    "MLRS": Artillery.MLRS_M270,
    "2S6 Tunguska": AirDefence.SAM_SA_19_Tunguska_2S6,
    "Kub 2P25 ln": AirDefence.SAM_SA_6_Kub_LN_2P25,
    "5p73 s-125 ln": AirDefence.SAM_SA_3_S_125_LN_5P73,
    "S-300PS 5P85C ln": AirDefence.SAM_SA_10_S_300PS_LN_5P85C,
    "S-300PS 5P85D ln": AirDefence.SAM_SA_10_S_300PS_LN_5P85D,
    "SA-11 Buk LN 9A310M1": AirDefence.SAM_SA_11_Buk_LN_9A310M1,
    "Osa 9A33 ln": AirDefence.SAM_SA_8_Osa_9A33,
    "Tor 9A331": AirDefence.SAM_SA_15_Tor_9A331,
    "Strela-10M3": AirDefence.SAM_SA_13_Strela_10M3_9A35M3,
    "Strela-1 9P31": AirDefence.SAM_SA_9_Strela_1_9P31,
    "SA-11 Buk CC 9S470M1": AirDefence.SAM_SA_11_Buk_CC_9S470M1,
    "SA-8 Osa LD 9T217": AirDefence.SAM_SA_8_Osa_LD_9T217,
    "Patriot AMG": AirDefence.SAM_Patriot_AMG_AN_MRC_137,
    "Patriot ECS": AirDefence.SAM_Patriot_ECS_AN_MSQ_104,
    "Gepard": AirDefence.SPAAA_Gepard,
    "Hawk pcp": AirDefence.SAM_Hawk_PCP,
    "Vulcan": AirDefence.AAA_Vulcan_M163,
    "Hawk ln": AirDefence.SAM_Hawk_LN_M192,
    "M48 Chaparral": AirDefence.SAM_Chaparral_M48,
    "M6 Linebacker": AirDefence.SAM_Linebacker_M6,
    "Patriot ln": AirDefence.SAM_Patriot_LN_M901,
    "M1097 Avenger": AirDefence.SAM_Avenger_M1097,
    "Patriot EPP": AirDefence.SAM_Patriot_EPP_III,
    "Patriot cp": AirDefence.SAM_Patriot_ICC,
    "Roland ADS": AirDefence.SAM_Roland_ADS,
    "S-300PS 54K6 cp": AirDefence.SAM_SA_10_S_300PS_CP_54K6,
    "Soldier stinger": AirDefence.Stinger_MANPADS,
    "Stinger comm dsr": AirDefence.SAM_Stinger_comm_dsr,
    "Stinger comm": AirDefence.SAM_Stinger_comm,
    "ZSU-23-4 Shilka": AirDefence.SPAAA_ZSU_23_4_Shilka,
    "ZU-23 Emplacement Closed": AirDefence.AAA_ZU_23_Closed,
    "ZU-23 Emplacement": AirDefence.AAA_ZU_23_Emplacement,
    "Ural-375 ZU-23": AirDefence.AAA_ZU_23_on_Ural_375,
    "ZU-23 Closed Insurgent": AirDefence.AAA_ZU_23_Insurgent_Closed,
    "Ural-375 ZU-23 Insurgent": AirDefence.AAA_ZU_23_Insurgent_on_Ural_375,
    "ZU-23 Insurgent": AirDefence.AAA_ZU_23_Insurgent,
    "SA-18 Igla manpad": AirDefence.SAM_SA_18_Igla_MANPADS,
    "SA-18 Igla comm": AirDefence.SAM_SA_18_Igla_comm,
    "SA-18 Igla-S manpad": AirDefence.SAM_SA_18_Igla_S_MANPADS,
    "SA-18 Igla-S comm": AirDefence.SAM_SA_18_Igla_S_comm,
    "Igla manpad INS": AirDefence.SAM_SA_18_Igla_MANPADS,
    "1L13 EWR": AirDefence.EWR_1L13,
    "Kub 1S91 str": AirDefence.SAM_SA_6_Kub_STR_9S91,
    "S-300PS 40B6M tr": AirDefence.SAM_SA_10_S_300PS_TR_30N6,
    "S-300PS 40B6MD sr": AirDefence.SAM_SA_10_S_300PS_SR_5N66M,
    "55G6 EWR": AirDefence.EWR_55G6,
    "S-300PS 64H6E sr": AirDefence.SAM_SA_10_S_300PS_SR_64H6E,
    "SA-11 Buk SR 9S18M1": AirDefence.SAM_SA_11_Buk_SR_9S18M1,
    "Dog Ear radar": AirDefence.CP_9S80M1_Sborka,
    "Hawk tr": AirDefence.SAM_Hawk_TR_AN_MPQ_46,
    "Hawk sr": AirDefence.SAM_Hawk_SR_AN_MPQ_50,
    "Patriot str": AirDefence.SAM_Patriot_STR_AN_MPQ_53,
    "Hawk cwar": AirDefence.SAM_Hawk_CWAR_AN_MPQ_55,
    "p-19 s-125 sr": AirDefence.SAM_SA_3_S_125_SR_P_19,
    "Roland Radar": AirDefence.SAM_Roland_EWR,
    "snr s-125 tr": AirDefence.SAM_SA_3_S_125_TR_SNR,
    "house1arm": Fortification.Barracks_armed,
    "house2arm": Fortification.Watch_tower_armed,
    "outpost_road": Fortification.Road_outpost,
    "outpost": Fortification.Outpost,
    "houseA_arm": Fortification.Armed_house,
    "Challenger2": Armor.MBT_Challenger_II,
    "Leclerc": Armor.MBT_Leclerc,
    "Leopard-2": Armor.MBT_Leopard_2,
    "M-60": Armor.MBT_M60A3_Patton,
    "M1128 Stryker MGS": Armor.SPG_M1128_Stryker_MGS,
    "M-1 Abrams": Armor.MBT_M1A2_Abrams,
    "T-55": Armor.MBT_T_55,
    "T-72B": Armor.MBT_T_72B,
    "T-80UD": Armor.MBT_T_80U,
    "T-90": Armor.MBT_T_90,
    "Leopard1A3": Armor.MBT_Leopard_1A3,
    "Merkava_Mk4": Armor.MBT_Merkava_Mk__4,
    "Ural-4320 APA-5D": Unarmed.GPU_APA_5D_on_Ural_4320,
    "ATMZ-5": Unarmed.Fuel_Truck_ATMZ_5,
    "ATZ-10": Unarmed.Fuel_Truck_ATZ_10,
    "GAZ-3307": Unarmed.Transport_GAZ_3307,
    "GAZ-3308": Unarmed.Transport_GAZ_3308,
    "GAZ-66": Unarmed.Transport_GAZ_66,
    "M978 HEMTT Tanker": Unarmed.Tanker_M978_HEMTT,
    "HEMTT TFFT": Unarmed.HEMTT_TFFT,
    "IKARUS Bus": Unarmed.Transport_IKARUS_280,
    "KAMAZ Truck": Unarmed.Transport_KAMAZ_43101,
    "LAZ Bus": Unarmed.Transport_LAZ_695,
    "Hummer": Unarmed.APC_M1025_HMMWV,
    "M 818": Unarmed.Transport_M818,
    "MAZ-6303": Unarmed.Transport_MAZ_6303,
    "Predator GCS": Unarmed.CP_Predator_GCS,
    "Predator TrojanSpirit": Unarmed.CP_Predator_TrojanSpirit,
    "Suidae": Unarmed.Suidae,
    "Tigr_233036": Unarmed.APC_Tigr_233036,
    "Trolley bus": Unarmed.Transport_ZIU_9,
    "UAZ-469": Unarmed.Transport_UAZ_469,
    "Ural ATsP-6": Unarmed.Transport_fire_Engine_Ural_ATsP_6,
    "Ural-4320-31": Unarmed.Transport_Ural_4320_31_Armored,
    "Ural-4320T": Unarmed.Transport_Ural_4320T,
    "Ural-375 PBU": Unarmed.CP_Ural_375_PBU,
    "Ural-375": Unarmed.Transport_Ural_375,
    "VAZ Car": Unarmed.Transport_VAZ_2109,
    "ZiL-131 APA-80": Unarmed.GPU_APA_80_on_ZiL_131,
    "SKP-11": Unarmed.CP_SKP_11_ATC_Mobile_Command_Post,
    "ZIL-131 KUNG": Unarmed.Transport_ZIL_131_KUNG,
    "ZIL-4331": Unarmed.Transport_ZIL_4331,
    "KrAZ6322": Unarmed.Transport_KrAZ_6322,
}
